==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebFilteringExpressionsTreeDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebFilteringExpressionsTreeDetailDescription = /*@__PURE__*/ (() => {
    class WebFilteringExpressionsTreeDetailDescription extends Description {
        constructor() {
            super();
            this.f = null;
            this.k = null;
            this.j = null;
            this.l = null;
        }
        get_type() {
            return "WebFilteringExpressionsTreeDetail";
        }
        get type() {
            return this.get_type();
        }
        get filteringOperands() {
            return this.f;
        }
        set filteringOperands(a) {
            this.f = a;
            this.e("FilteringOperands");
        }
        get operator() {
            return this.k;
        }
        set operator(a) {
            this.k = a;
            this.e("Operator");
        }
        get fieldName() {
            return this.j;
        }
        set fieldName(a) {
            this.j = a;
            this.e("FieldName");
        }
        get treeType() {
            return this.l;
        }
        set treeType(a) {
            this.l = a;
            this.e("TreeType");
        }
    }
    WebFilteringExpressionsTreeDetailDescription.$t = /*@__PURE__*/ markType(WebFilteringExpressionsTreeDetailDescription, 'WebFilteringExpressionsTreeDetailDescription', Description.$);
    WebFilteringExpressionsTreeDetailDescription.__marshalByValue = true;
    WebFilteringExpressionsTreeDetailDescription.__marshalByValueAlias = "FilteringExpressionsTreeDetail";
    return WebFilteringExpressionsTreeDetailDescription;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebFilteringExpressionsTreeDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebFilteringExpressionsTreeDetailDescription = /*@__PURE__*/ (() => {
    class WebFilteringExpressionsTreeDetailDescription extends Description {
        get_type() {
            return "WebFilteringExpressionsTreeDetail";
        }
        get type() {
            return this.get_type();
        }
        constructor() {
            super();
            this.h = null;
            this.s = null;
            this.m = null;
            this.r = null;
            this.q = null;
            this.p = null;
            this.i = null;
        }
        get filteringOperands() {
            return this.h;
        }
        set filteringOperands(a) {
            this.h = a;
            this.g("FilteringOperands");
        }
        get treeType() {
            return this.s;
        }
        set treeType(a) {
            this.s = a;
            this.g("TreeType");
        }
        get owner() {
            return this.m;
        }
        set owner(a) {
            this.m = a;
            this.g("Owner");
        }
        get operator() {
            return this.r;
        }
        set operator(a) {
            this.r = a;
            this.g("Operator");
        }
        get fieldName() {
            return this.q;
        }
        set fieldName(a) {
            this.q = a;
            this.g("FieldName");
        }
        get entity() {
            return this.p;
        }
        set entity(a) {
            this.p = a;
            this.g("Entity");
        }
        get returnFields() {
            return this.i;
        }
        set returnFields(a) {
            this.i = a;
            this.g("ReturnFields");
        }
    }
    WebFilteringExpressionsTreeDetailDescription.$t = /*@__PURE__*/ markType(WebFilteringExpressionsTreeDetailDescription, 'WebFilteringExpressionsTreeDetailDescription', Description.$);
    WebFilteringExpressionsTreeDetailDescription.__marshalByValue = true;
    WebFilteringExpressionsTreeDetailDescription.__marshalByValueAlias = "FilteringExpressionsTreeDetail";
    return WebFilteringExpressionsTreeDetailDescription;
})();
